==> tabular-data-gwt-service-2.2.0-20140625.141438-106-sources.jar: org/gcube/portlets/user/td/gwtservice/server/file/CodelistMappingFileUploadSession.java <==
package org.gcube.portlets.user.td.gwtservice.server.file;

import java.io.File;
import java.io.Serializable;

import org.gcube.portlets.user.td.gwtservice.shared.codelisthelper.CodelistMappingMonitor;
import org.gcube.portlets.user.td.gwtservice.shared.file.FileUploadState;

/**
 * 
 * @author "Giancarlo Panichi" <a
 *         href="mailto:g.panichi@isti.cnr.it">g.panichi@isti.cnr.it</a>
 * 
 */
public class CodelistMappingFileUploadSession implements Serializable {

	private static final long serialVersionUID = -5683392670926072167L;

	protected String id;

	protected FileUploadState fileUploadState;

	protected File codelistMappingFile;
	protected String codelistMappingName;

	protected CodelistMappingMonitor codelistMappingMonitor;

	public String getId() {
		return id;
	}

	public void setId(String id) {
		this.id = id;
	}

	public FileUploadState getFileUploadState() {
		return fileUploadState;
	}

	public void setFileUploadState(FileUploadState fileUploadState) {
		this.fileUploadState = fileUploadState;
	}

	
	public File getCodelistMappingFile() {
		return codelistMappingFile;
	}

	public void setCodelistMappingFile(File codelistMappingFile) {
		this.codelistMappingFile = codelistMappingFile;
	}

	public String getCodelistMappingName() {
		return codelistMappingName;
	}

	public void setCodelistMappingName(String codelistMappingName) {
		this.codelistMappingName = codelistMappingName;
	}

	public CodelistMappingMonitor getCodelistMappingMonitor() {
		return codelistMappingMonitor;
	}

	public void setCodelistMappingMonitor(
			CodelistMappingMonitor codelistMappingMonitor) {
		this.codelistMappingMonitor = codelistMappingMonitor;
	}

	@Override
	public String toString() {
		return "CodelistMappingFileUploadSession [id=" + id
				+ ", fileUploadState=" + fileUploadState
				+ ", codelistMappingFile=" + codelistMappingFile
				+ ", codelistMappingName=" + codelistMappingName
				+ ", codelistMappingMonitor=" + codelistMappingMonitor + "]";
	}

	
}

==> tabular-data-gwt-service-2.9.0-20151109.172532-47-sources.jar: org/gcube/portlets/user/td/gwtservice/server/file/CodelistMappingFileUploadSession.java <==
package org.gcube.portlets.user.td.gwtservice.server.file;

import java.io.File;
import java.io.Serializable;

import org.gcube.portlets.user.td.gwtservice.shared.file.FileUploadState;

/**
 * 
 * @author "Giancarlo Panichi" <a
 *         href="mailto:g.panichi@isti.cnr.it">g.panichi@isti.cnr.it</a>
 * 
 */
public class CodelistMappingFileUploadSession implements Serializable {

	private static final long serialVersionUID = -5683392670926072167L;

	protected String id;

	protected FileUploadState fileUploadState;

	protected File codelistMappingFile;
	protected String codelistMappingName;

	//protected CodelistMappingMonitor codelistMappingMonitor;

	public String getId() {
		return id;
	}

	public void setId(String id) {
		this.id = id;
	}

	public FileUploadState getFileUploadState() {
		return fileUploadState;
	}

	public void setFileUploadState(FileUploadState fileUploadState) {
		this.fileUploadState = fileUploadState;
	}

	
	public File getCodelistMappingFile() {
		return codelistMappingFile;
	}

	public void setCodelistMappingFile(File codelistMappingFile) {
		this.codelistMappingFile = codelistMappingFile;
	}

	public String getCodelistMappingName() {
		return codelistMappingName;
	}

	public void setCodelistMappingName(String codelistMappingName) {
		this.codelistMappingName = codelistMappingName;
	}

	@Override
	public String toString() {
		return "CodelistMappingFileUploadSession [id=" + id
				+ ", fileUploadState=" + fileUploadState
				+ ", codelistMappingFile=" + codelistMappingFile
				+ ", codelistMappingName=" + codelistMappingName + "]";
	}

	
	
	
	
}
